@@ -3,8 +3,10 @@ try:
 except ImportError:
     __version__ = "unknown"
 
-from ._widget import batch_annotator
+from ._widget import batch_annotator, batch_predict, batch_training
 
 __all__ = [
     "batch_annotator",
+    "batch_training",
+    "batch_predict",
 ]
